Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressNode.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressNode.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressNode.java	(revision 24089)
@@ -275,5 +275,5 @@
 	 */
 	@Override
-	public int compareTo(INodeEntity o) {
+	public int compareTo(IOSMEntity o) {
 		if (o == null || !(o instanceof AddressNode)) {
 			return -1;
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IAddressEditContainerListener.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IAddressEditContainerListener.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IAddressEditContainerListener.java	(revision 24089)
@@ -25,4 +25,4 @@
 	 * Notifies clients that an entity has been changed.
 	 */
-	public void entityChanged(INodeEntity node);
+	public void entityChanged(IOSMEntity node);
 }
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/ICommandListener.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/ICommandListener.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/ICommandListener.java	(revision 24089)
@@ -23,4 +23,4 @@
 	 * @param command The command instance to process by the enclosing command listener.
 	 */
-	public void commandIssued(INodeEntity entity, Command command);
+	public void commandIssued(IOSMEntity entity, Command command);
 }
Index: plications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/INodeEntity.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/INodeEntity.java	(revision 24088)
+++ 	(revision )
@@ -1,72 +1,0 @@
-/*
- * This program is free software: you can redistribute it and/or modify it under 
- * the terms of the GNU General Public License as published by the 
- * Free Software Foundation, either version 3 of the License, or 
- * (at your option) any later version. 
- * 
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
- * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
- * See the GNU General Public License for more details. 
- * 
- * You should have received a copy of the GNU General Public License along with this program. 
- * If not, see <http://www.gnu.org/licenses/>.
- */
-package org.openstreetmap.josm.plugins.fixAddresses;
-
-import java.util.List;
-
-import org.openstreetmap.josm.data.coor.LatLon;
-import org.openstreetmap.josm.data.osm.OsmPrimitive;
-
-/**
- * Base interface for all node entities. A node entity is a lightweight wrapper
- * around OSM objects in order to ease up some tasks like tag handling.
- * @author Oliver Wieland <oliver.wieland@online.de>
- * 
- */
-
-public interface INodeEntity extends Comparable<INodeEntity> {
-	/**
-	 * Gets the underlying OSM object.
-	 * @return
-	 */
-	public OsmPrimitive getOsmObject();
-	
-	/**
-	 * Checks if underlying OSM object has a name.
-	 * @return
-	 */
-	public boolean hasName();
-	
-	/**
-	 * Gets the name of the entity node.
-	 * @return
-	 */
-	public String getName();
-	
-	/**
-	 * Gets the children of the entity node.
-	 * @return
-	 */
-	public List<INodeEntity> getChildren();
-	
-	/**
-	 * Gets the coordinate of the node. If the the underlying object is a
-	 * node, it just returns the node coordinate. For ways and areas, this 
-	 * method returns the coordinate of the center (balance point). 
-	 * @return
-	 */
-	public LatLon getCoor();
-	
-	/**
-	 * Adds a command listener.
-	 * @param listener
-	 */
-	public void addCommandListener(ICommandListener listener);
-	
-	/**
-	 * Removes a command listener.
-	 * @param listener
-	 */
-	public void removeCommandListener(ICommandListener listener);
-}
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IOSMEntity.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IOSMEntity.java	(revision 24089)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/IOSMEntity.java	(revision 24089)
@@ -0,0 +1,72 @@
+/*
+ * This program is free software: you can redistribute it and/or modify it under 
+ * the terms of the GNU General Public License as published by the 
+ * Free Software Foundation, either version 3 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
+ * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
+ * See the GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License along with this program. 
+ * If not, see <http://www.gnu.org/licenses/>.
+ */
+package org.openstreetmap.josm.plugins.fixAddresses;
+
+import java.util.List;
+
+import org.openstreetmap.josm.data.coor.LatLon;
+import org.openstreetmap.josm.data.osm.OsmPrimitive;
+
+/**
+ * Base interface for all node entities. A node entity is a lightweight wrapper
+ * around OSM objects in order to ease up some tasks like tag handling.
+ * @author Oliver Wieland <oliver.wieland@online.de>
+ * 
+ */
+
+public interface IOSMEntity extends Comparable<IOSMEntity> {
+	/**
+	 * Gets the underlying OSM object.
+	 * @return
+	 */
+	public OsmPrimitive getOsmObject();
+	
+	/**
+	 * Checks if underlying OSM object has a name.
+	 * @return
+	 */
+	public boolean hasName();
+	
+	/**
+	 * Gets the name of the entity node.
+	 * @return
+	 */
+	public String getName();
+	
+	/**
+	 * Gets the children of the entity node.
+	 * @return
+	 */
+	public List<IOSMEntity> getChildren();
+	
+	/**
+	 * Gets the coordinate of the node. If the the underlying object is a
+	 * node, it just returns the node coordinate. For ways and areas, this 
+	 * method returns the coordinate of the center (balance point). 
+	 * @return
+	 */
+	public LatLon getCoor();
+	
+	/**
+	 * Adds a command listener.
+	 * @param listener
+	 */
+	public void addCommandListener(ICommandListener listener);
+	
+	/**
+	 * Removes a command listener.
+	 * @param listener
+	 */
+	public void removeCommandListener(ICommandListener listener);
+}
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeFactory.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeFactory.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeFactory.java	(revision 24089)
@@ -49,5 +49,5 @@
 	 * @return The new node instance or null; if given way is inappropriate.
 	 */
-	public static INodeEntity createNodeFromWay(Way way) {
+	public static IOSMEntity createNodeFromWay(Way way) {
 		if (TagUtils.hasHighwayTag(way)) {
 			return new StreetSegmentNode(way);
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetNode.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetNode.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetNode.java	(revision 24089)
@@ -27,5 +27,5 @@
  */
 public class StreetNode extends NodeEntityBase {
-	private List<INodeEntity> children;
+	private List<IOSMEntity> children;
 	private List<AddressNode> addresses;
 			
@@ -37,5 +37,5 @@
 	}
 
-	public List<INodeEntity> getChildren() {
+	public List<IOSMEntity> getChildren() {
 		return children;
 	}
@@ -54,5 +54,5 @@
 	private void lazyCreateChildren() {
 		if (children == null) {
-			children = new ArrayList<INodeEntity>();
+			children = new ArrayList<IOSMEntity>();
 		}
 	}
@@ -99,5 +99,5 @@
 		
 		int sc = 0;
-		for (INodeEntity node : children) {
+		for (IOSMEntity node : children) {
 			if (node instanceof StreetSegmentNode) {
 				sc++;
@@ -115,5 +115,5 @@
 		List<String> types = new ArrayList<String>();
 		
-		for (INodeEntity seg : getChildren()) {
+		for (IOSMEntity seg : getChildren()) {
 			OsmPrimitive osmPrim = seg.getOsmObject();
 			if (TagUtils.hasHighwayTag(osmPrim)) {
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetSegmentNode.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetSegmentNode.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/StreetSegmentNode.java	(revision 24089)
@@ -33,5 +33,5 @@
 
 	@Override
-	public List<INodeEntity> getChildren() {
+	public List<IOSMEntity> getChildren() {
 		return null;
 	}
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AbstractAddressEditAction.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AbstractAddressEditAction.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AbstractAddressEditAction.java	(revision 24089)
@@ -25,5 +25,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener;
 import org.openstreetmap.josm.plugins.fixAddresses.ICommandListener;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 import org.openstreetmap.josm.plugins.fixAddresses.StringUtils;
 
@@ -170,8 +170,8 @@
 
 	/* (non-Javadoc)
-	 * @see org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener#entityChanged(org.openstreetmap.josm.plugins.fixAddresses.INodeEntity)
-	 */
-	@Override
-	public void entityChanged(INodeEntity node) {
+	 * @see org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener#entityChanged(org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity)
+	 */
+	@Override
+	public void entityChanged(IOSMEntity node) {
 		updateEnabledState();		
 	}
@@ -213,5 +213,5 @@
 	 * @param entity the entity
 	 */
-	public void beginObjectTransaction(INodeEntity entity) {
+	public void beginObjectTransaction(IOSMEntity entity) {
 		if (entity != null) {
 			entity.addCommandListener(this);
@@ -226,5 +226,5 @@
 	 * @param entity the entity
 	 */
-	public void finishObjectTransaction(INodeEntity entity) {
+	public void finishObjectTransaction(IOSMEntity entity) {
 		if (entity != null) {
 			entity.removeCommandListener(this);
@@ -235,8 +235,8 @@
 	
 	/* (non-Javadoc)
-	 * @see org.openstreetmap.josm.plugins.fixAddresses.ICommandListener#commandIssued(org.openstreetmap.josm.plugins.fixAddresses.INodeEntity, org.openstreetmap.josm.command.Command)
-	 */
-	@Override
-	public void commandIssued(INodeEntity entity, Command command) {
+	 * @see org.openstreetmap.josm.plugins.fixAddresses.ICommandListener#commandIssued(org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity, org.openstreetmap.josm.command.Command)
+	 */
+	@Override
+	public void commandIssued(IOSMEntity entity, Command command) {
 		if (commands == null) {
 			throw new RuntimeException("No command list available. Did you forget to call beginTransaction?");
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditDialog.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditDialog.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditDialog.java	(revision 24089)
@@ -52,5 +52,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.AddressNode;
 import org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 import org.openstreetmap.josm.plugins.fixAddresses.StreetNode;
 import org.openstreetmap.josm.plugins.fixAddresses.StringUtils;
@@ -264,5 +264,5 @@
 						
 			//mapViewer.addMapRectangle(new BBoxMapRectangle(bb));
-			for (INodeEntity seg : sNode.getChildren()) {
+			for (IOSMEntity seg : sNode.getChildren()) {
 				Way way = (Way) seg.getOsmObject();
 				//BBox bb = way.getBBox();
@@ -316,5 +316,5 @@
 
 	@Override
-	public void entityChanged(INodeEntity entity) {
+	public void entityChanged(IOSMEntity entity) {
 		updateHeaders();
 	}
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditModel.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditModel.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditModel.java	(revision 24089)
@@ -23,5 +23,5 @@
 
 import org.openstreetmap.josm.plugins.fixAddresses.AddressNode;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 import org.openstreetmap.josm.plugins.fixAddresses.StreetNode;
 
@@ -57,5 +57,5 @@
 				
 				// Add street segment(s)
-				for (INodeEntity child : sNode.getChildren()) {
+				for (IOSMEntity child : sNode.getChildren()) {
 					segmentsNode.add(new DefaultMutableTreeNode(child));
 				}
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditTableModel.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditTableModel.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/AddressEditTableModel.java	(revision 24089)
@@ -18,5 +18,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.AddressEditContainer;
 import org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 
 public abstract class AddressEditTableModel extends DefaultTableModel implements IAddressEditContainerListener{
@@ -40,5 +40,5 @@
 
 	@Override
-	public void entityChanged(INodeEntity entity) {
+	public void entityChanged(IOSMEntity entity) {
 		int row = getRowOfEntity(entity);
 		if (row != -1) { // valid row? -> update model
@@ -53,5 +53,5 @@
 	 * @return
 	 */
-	public abstract INodeEntity getEntityOfRow(int row);
+	public abstract IOSMEntity getEntityOfRow(int row);
 	
 	/**
@@ -60,4 +60,4 @@
 	 * @return
 	 */
-	public abstract int getRowOfEntity(INodeEntity entity);
+	public abstract int getRowOfEntity(IOSMEntity entity);
 }
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/ApplyAllGuessesAction.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/ApplyAllGuessesAction.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/ApplyAllGuessesAction.java	(revision 24089)
@@ -26,5 +26,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.AddressEditContainer;
 import org.openstreetmap.josm.plugins.fixAddresses.AddressNode;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 
 /**
@@ -87,5 +87,5 @@
 			if (model != null) {
 				int row = table.rowAtPoint(p);
-				INodeEntity node = model.getEntityOfRow(row);
+				IOSMEntity node = model.getEntityOfRow(row);
 				if (node instanceof AddressNode) {
 					beginTransaction(tr("Applied guessed values for ") + node.getOsmObject());
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/IncompleteAddressesTableModel.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/IncompleteAddressesTableModel.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/IncompleteAddressesTableModel.java	(revision 24089)
@@ -18,5 +18,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.AddressEditContainer;
 import org.openstreetmap.josm.plugins.fixAddresses.AddressNode;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 
 public class IncompleteAddressesTableModel extends AddressEditTableModel  {
@@ -95,5 +95,5 @@
 
 	@Override
-	public INodeEntity getEntityOfRow(int row) {
+	public IOSMEntity getEntityOfRow(int row) {
 		if (addressContainer == null || addressContainer.getIncompleteAddresses() == null) {
 			return null;
@@ -106,5 +106,5 @@
 
 	@Override
-	public int getRowOfEntity(INodeEntity entity) {
+	public int getRowOfEntity(IOSMEntity entity) {
 		if (addressContainer == null || addressContainer.getIncompleteAddresses() == null) {
 			return -1;
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/StreetTableModel.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/StreetTableModel.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/StreetTableModel.java	(revision 24089)
@@ -17,5 +17,5 @@
 
 import org.openstreetmap.josm.plugins.fixAddresses.AddressEditContainer;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 import org.openstreetmap.josm.plugins.fixAddresses.StreetNode;
 
@@ -107,5 +107,5 @@
 
 	@Override
-	public INodeEntity getEntityOfRow(int row) {
+	public IOSMEntity getEntityOfRow(int row) {
 		if (addressContainer == null || addressContainer.getStreetList() == null) {
 			return null;
@@ -118,5 +118,5 @@
 	
 	@Override
-	public int getRowOfEntity(INodeEntity entity) {
+	public int getRowOfEntity(IOSMEntity entity) {
 		if (addressContainer == null || addressContainer.getStreetList() == null) {
 			return -1;
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/UnresolvedAddressesTableModel.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/UnresolvedAddressesTableModel.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/gui/UnresolvedAddressesTableModel.java	(revision 24089)
@@ -33,5 +33,5 @@
 import org.openstreetmap.josm.plugins.fixAddresses.AddressEditContainer;
 import org.openstreetmap.josm.plugins.fixAddresses.AddressNode;
-import org.openstreetmap.josm.plugins.fixAddresses.INodeEntity;
+import org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity;
 import org.openstreetmap.josm.plugins.fixAddresses.StringUtils;
 import org.openstreetmap.josm.plugins.fixAddresses.TagUtils;
@@ -144,5 +144,5 @@
 	 */
 	@Override
-	public INodeEntity getEntityOfRow(int row) {
+	public IOSMEntity getEntityOfRow(int row) {
 		if (addressContainer == null || addressContainer.getUnresolvedAddresses() == null) {
 			return null;
@@ -155,5 +155,5 @@
 	
 	@Override
-	public int getRowOfEntity(INodeEntity entity) {
+	public int getRowOfEntity(IOSMEntity entity) {
 		if (addressContainer == null || addressContainer.getUnresolvedAddresses() == null) {
 			return -1;

Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressEditContainer.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressEditContainer.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/AddressEditContainer.java	(revision 24089)
@@ -58,5 +58,5 @@
  * addresses with unknown streets ("unresolved addresses").
  * 
  * It listens to changes within instances of {@link INodeEntity} to notify clients on update. 
  * 
  * {@link AddressEditContainer} is the central class used within actions and UI models to show
@@ -150,5 +150,5 @@
 	 * Notifies clients that an entity within the address container changed.
 	 */
-	protected void fireEntityChanged(INodeEntity entity) {
+	protected void fireEntityChanged(IOSMEntity entity) {
 		if (entity == null) throw new RuntimeException("Entity must not be null");
 		
@@ -256,5 +256,5 @@
 	 */
 	private void createNodeFromWay(Way w) {
-		INodeEntity ne = NodeFactory.createNodeFromWay(w);
+		IOSMEntity ne = NodeFactory.createNodeFromWay(w);
 		
 		if (!processNode(ne, w)) {
@@ -287,5 +287,5 @@
 	 * @return true, if node has been processed
 	 */
-	private boolean processNode(INodeEntity ne, Way w) {
+	private boolean processNode(IOSMEntity ne, Way w) {
 		if (ne != null) {
 			// Node is a street (segment)
@@ -657,8 +657,8 @@
 
 	/* (non-Javadoc)
-	 * @see org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener#entityChanged(org.openstreetmap.josm.plugins.fixAddresses.INodeEntity)
-	 */
-	@Override
-	public void entityChanged(INodeEntity entity) {
+	 * @see org.openstreetmap.josm.plugins.fixAddresses.IAddressEditContainerListener#entityChanged(org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity)
+	 */
+	@Override
+	public void entityChanged(IOSMEntity entity) {
 		fireEntityChanged(entity);	
 	}
@@ -58,5 +58,5 @@
  * addresses with unknown streets ("unresolved addresses").
  * 
- * It listens to changes within instances of {@link INodeEntity} to notify clients on update. 
+ * It listens to changes within instances of {@link IOSMEntity} to notify clients on update. 
  * 
  * {@link AddressEditContainer} is the central class used within actions and UI models to show
Index: /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeEntityBase.java
===================================================================
--- /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeEntityBase.java	(revision 24088)
+++ /applications/editors/josm/plugins/FixAddresses/src/org/openstreetmap/josm/plugins/fixAddresses/NodeEntityBase.java	(revision 24089)
@@ -28,5 +28,5 @@
 
 /**
  * The class NodeEntityBase provides a base implementation for the {@link INodeEntity} interface.
  * 
  * The implementation comprises
@@ -37,5 +37,5 @@
  * </ol>
  */
-public class NodeEntityBase implements INodeEntity, Comparable<INodeEntity> {
+public class NodeEntityBase implements IOSMEntity, Comparable<IOSMEntity> {
 	public static final String ANONYMOUS = tr("No name");
 	private static List<IAddressEditContainerListener> containerListeners = new ArrayList<IAddressEditContainerListener>();
@@ -78,5 +78,5 @@
 	 * Notifies clients that the address container changed.
 	 */
-	protected static void fireEntityChanged(INodeEntity entity) {
+	protected static void fireEntityChanged(IOSMEntity entity) {
 		for (IAddressEditContainerListener listener : containerListeners) {
 			listener.entityChanged(entity);
@@ -121,5 +121,5 @@
 
 	@Override
-	public List<INodeEntity> getChildren() {
+	public List<IOSMEntity> getChildren() {
 		return null;
 	}
@@ -188,5 +188,5 @@
 	 */
 	@Override
-	public int compareTo(INodeEntity o) {
+	public int compareTo(IOSMEntity o) {
 		if (o == null || !(o instanceof NodeEntityBase)) return -1;
 		return this.getName().compareTo(o.getName());
@@ -194,5 +194,5 @@
 
 	/* (non-Javadoc)
-	 * @see org.openstreetmap.josm.plugins.fixAddresses.INodeEntity#getCoor()
+	 * @see org.openstreetmap.josm.plugins.fixAddresses.IOSMEntity#getCoor()
 	 */
 	@Override
@@ -28,5 +28,5 @@
 
 /**
- * The class NodeEntityBase provides a base implementation for the {@link INodeEntity} interface.
+ * The class NodeEntityBase provides a base implementation for the {@link IOSMEntity} interface.
  * 
  * The implementation comprises